@@ -590,9 +590,7 @@ from calibre.ebooks.conversion.plugins.txt_output import TXTOutput, TXTZOutput
 from calibre.ebooks.conversion.plugins.html_output import HTMLOutput
 from calibre.ebooks.conversion.plugins.htmlz_output import HTMLZOutput
 from calibre.ebooks.conversion.plugins.snb_output import SNBOutput
-if 'CALIBRE_ENABLE_EXPERIMENTAL_DOCX_OUTPUT' in os.environ:
-    from calibre.ebooks.conversion.plugins.docx_output import DOCXOutput
-    plugins.append(DOCXOutput)
+from calibre.ebooks.conversion.plugins.docx_output import DOCXOutput
 
 plugins += [
     ComicInput,
@@ -620,6 +618,7 @@ plugins += [
 ]
 plugins += [
     EPUBOutput,
+    DOCXOutput,
     FB2Output,
     LITOutput,
     LRFOutput,
