@@ -121,7 +121,7 @@ class LibraryDatabase(object):
         return self.backend.dbpath
 
     def last_modified(self):
-        return self.backend.last_modified()
+        return self.new_api.last_modified()
 
     def check_if_modified(self):
         if self.last_modified() > self.last_update_check:
@@ -259,13 +259,13 @@ class LibraryDatabase(object):
         return recursive_import(self, root, single_book_per_directory=single_book_per_directory, callback=callback, added_ids=added_ids)
 
     def add_catalog(self, path, title):
-        book_id, new_book_added = add_catalog(self.new_api, path, title)
+        book_id, new_book_added = add_catalog(self.new_api, path, title, dbapi=self)
         if book_id is not None and new_book_added:
             self.data.books_added((book_id,))
         return book_id
 
     def add_news(self, path, arg):
-        book_id = add_news(self.new_api, path, arg)
+        book_id = add_news(self.new_api, path, arg, dbapi=self)
         if book_id is not None:
             self.data.books_added((book_id,))
         return book_id
