@@ -6,7 +6,7 @@ from __future__ import (unicode_literals, division, absolute_import,
 __license__ = 'GPL v3'
 __copyright__ = '2013, Kovid Goyal <kovid at kovidgoyal.net>'
 
-import sys, os, re, math
+import sys, os, re, math, errno
 from collections import OrderedDict, defaultdict
 
 from lxml import html
@@ -15,9 +15,7 @@ from lxml.html.builder import (
 
 from calibre import guess_type
 from calibre.ebooks.docx.container import DOCX, fromstring
-from calibre.ebooks.docx.names import (
-    XPath, is_tag, XML, STYLES, NUMBERING, FONTS, get, generate_anchor,
-    descendants, FOOTNOTES, ENDNOTES, children, THEMES, SETTINGS)
+from calibre.ebooks.docx.names import XML, generate_anchor
 from calibre.ebooks.docx.styles import Styles, inherit, PageProperties
 from calibre.ebooks.docx.numbering import Numbering
 from calibre.ebooks.docx.fonts import Fonts
@@ -52,22 +50,24 @@ def html_lang(docx_lang):
 
 class Convert(object):
 
-    def __init__(self, path_or_stream, dest_dir=None, log=None, detect_cover=True, notes_text=None):
+    def __init__(self, path_or_stream, dest_dir=None, log=None, detect_cover=True, notes_text=None, notes_nopb=False):
         self.docx = DOCX(path_or_stream, log=log)
+        self.namespace = self.docx.namespace
         self.ms_pat = re.compile(r'\s{2,}')
         self.ws_pat = re.compile(r'[\n\r\t]')
         self.log = self.docx.log
         self.detect_cover = detect_cover
         self.notes_text = notes_text or _('Notes')
+        self.notes_nopb = notes_nopb
         self.dest_dir = dest_dir or os.getcwdu()
         self.mi = self.docx.metadata
         self.body = BODY()
-        self.theme = Theme()
-        self.settings = Settings()
-        self.tables = Tables()
-        self.fields = Fields()
-        self.styles = Styles(self.tables)
-        self.images = Images(self.log)
+        self.theme = Theme(self.namespace)
+        self.settings = Settings(self.namespace)
+        self.tables = Tables(self.namespace)
+        self.fields = Fields(self.namespace)
+        self.styles = Styles(self.namespace, self.tables)
+        self.images = Images(self.namespace, self.log)
         self.object_map = OrderedDict()
         self.html = HTML(
             HEAD(
@@ -211,7 +211,7 @@ class Convert(object):
                 html_obj.set('class', cls)
 
         if notes_header is not None:
-            for h in children(self.body, 'h1', 'h2', 'h3'):
+            for h in self.namespace.children(self.body, 'h1', 'h2', 'h3'):
                 notes_header.tag = h.tag
                 cls = h.get('class', None)
                 if cls and cls != 'notes-header':
@@ -221,7 +221,7 @@ class Convert(object):
         self.fields.polish_markup(self.object_map)
 
         self.log.debug('Cleaning up redundant markup generated by Word')
-        self.cover_image = cleanup_markup(self.log, self.html, self.styles, self.dest_dir, self.detect_cover)
+        self.cover_image = cleanup_markup(self.log, self.html, self.styles, self.dest_dir, self.detect_cover, self.namespace.XPath)
 
         return self.write(doc)
 
@@ -230,14 +230,14 @@ class Convert(object):
         self.page_map = OrderedDict()
         self.section_starts = []
 
-        for p in descendants(doc, 'w:p', 'w:tbl'):
+        for p in self.namespace.descendants(doc, 'w:p', 'w:tbl'):
             if p.tag.endswith('}tbl'):
                 self.tables.register(p, self.styles)
                 current.append(p)
                 continue
-            sect = tuple(descendants(p, 'w:sectPr'))
+            sect = tuple(self.namespace.descendants(p, 'w:sectPr'))
             if sect:
-                pr = PageProperties(sect)
+                pr = PageProperties(self.namespace, sect)
                 paras = current + [p]
                 for x in paras:
                     self.page_map[x] = pr
@@ -248,8 +248,8 @@ class Convert(object):
 
         if current:
             self.section_starts.append(current[0])
-            last = XPath('./w:body/w:sectPr')(doc)
-            pr = PageProperties(last)
+            last = self.namespace.XPath('./w:body/w:sectPr')(doc)
+            pr = PageProperties(self.namespace, last)
             for x in current:
                 self.page_map[x] = pr
 
@@ -264,16 +264,16 @@ class Convert(object):
                     name = name
             return name
 
-        nname = get_name(NUMBERING, 'numbering.xml')
-        sname = get_name(STYLES, 'styles.xml')
-        sename = get_name(SETTINGS, 'settings.xml')
-        fname = get_name(FONTS, 'fontTable.xml')
-        tname = get_name(THEMES, 'theme1.xml')
-        foname = get_name(FOOTNOTES, 'footnotes.xml')
-        enname = get_name(ENDNOTES, 'endnotes.xml')
-        numbering = self.numbering = Numbering()
-        footnotes = self.footnotes = Footnotes()
-        fonts = self.fonts = Fonts()
+        nname = get_name(self.namespace.names['NUMBERING'], 'numbering.xml')
+        sname = get_name(self.namespace.names['STYLES'], 'styles.xml')
+        sename = get_name(self.namespace.names['SETTINGS'], 'settings.xml')
+        fname = get_name(self.namespace.names['FONTS'], 'fontTable.xml')
+        tname = get_name(self.namespace.names['THEMES'], 'theme1.xml')
+        foname = get_name(self.namespace.names['FOOTNOTES'], 'footnotes.xml')
+        enname = get_name(self.namespace.names['ENDNOTES'], 'endnotes.xml')
+        numbering = self.numbering = Numbering(self.namespace)
+        footnotes = self.footnotes = Footnotes(self.namespace)
+        fonts = self.fonts = Fonts(self.namespace)
 
         foraw = enraw = None
         forel, enrel = ({}, {}), ({}, {})
@@ -282,6 +282,10 @@ class Convert(object):
                 seraw = self.docx.read(sename)
             except KeyError:
                 self.log.warn('Settings %s do not exist' % sename)
+            except EnvironmentError as e:
+                if e.errno != errno.ENOENT:
+                    raise
+                self.log.warn('Settings %s file missing' % sename)
             else:
                 self.settings(fromstring(seraw))
 
@@ -337,11 +341,11 @@ class Convert(object):
         self.styles.resolve_numbering(numbering)
 
     def write(self, doc):
-        toc = create_toc(doc, self.body, self.resolved_link_map, self.styles, self.object_map, self.log)
+        toc = create_toc(doc, self.body, self.resolved_link_map, self.styles, self.object_map, self.log, self.namespace)
         raw = html.tostring(self.html, encoding='utf-8', doctype='<!DOCTYPE html>')
         with open(os.path.join(self.dest_dir, 'index.html'), 'wb') as f:
             f.write(raw)
-        css = self.styles.generate_css(self.dest_dir, self.docx)
+        css = self.styles.generate_css(self.dest_dir, self.docx, self.notes_nopb)
         if css:
             with open(os.path.join(self.dest_dir, 'docx.css'), 'wb') as f:
                 f.write(css.encode('utf-8'))
@@ -363,11 +367,11 @@ class Convert(object):
         return os.path.join(self.dest_dir, 'metadata.opf')
 
     def read_block_anchors(self, doc):
-        doc_anchors = frozenset(XPath('./w:body/w:bookmarkStart[@w:name]')(doc))
+        doc_anchors = frozenset(self.namespace.XPath('./w:body/w:bookmarkStart[@w:name]')(doc))
         if doc_anchors:
             current_bm = set()
             rmap = {v:k for k, v in self.object_map.iteritems()}
-            for p in descendants(doc, 'w:p', 'w:bookmarkStart[@w:name]'):
+            for p in self.namespace.descendants(doc, 'w:p', 'w:bookmarkStart[@w:name]'):
                 if p.tag.endswith('}p'):
                     if current_bm and p in rmap:
                         para = rmap[p]
@@ -377,7 +381,7 @@ class Convert(object):
                             self.anchor_map[name] = para.get('id')
                         current_bm = set()
                 elif p in doc_anchors:
-                    anchor = get(p, 'w:name')
+                    anchor = self.namespace.get(p, 'w:name')
                     if anchor:
                         current_bm.add(anchor)
 
@@ -390,7 +394,7 @@ class Convert(object):
 
         current_anchor = None
         current_hyperlink = None
-        hl_xpath = XPath('ancestor::w:hyperlink[1]')
+        hl_xpath = self.namespace.XPath('ancestor::w:hyperlink[1]')
 
         def p_parent(x):
             # Ensure that nested <w:p> tags are handled. These can occur if a
@@ -403,7 +407,7 @@ class Convert(object):
                 except AttributeError:
                     break
 
-        for x in descendants(p, 'w:r', 'w:bookmarkStart', 'w:hyperlink'):
+        for x in self.namespace.descendants(p, 'w:r', 'w:bookmarkStart', 'w:hyperlink'):
             if p_parent(x) is not p:
                 continue
             if x.tag.endswith('}r'):
@@ -422,7 +426,7 @@ class Convert(object):
                 dest.append(span)
                 self.layers[p].append(x)
             elif x.tag.endswith('}bookmarkStart'):
-                anchor = get(x, 'w:name')
+                anchor = self.namespace.get(x, 'w:name')
                 if anchor and anchor not in self.anchor_map:
                     old_anchor = current_anchor
                     self.anchor_map[anchor] = current_anchor = generate_anchor(anchor, frozenset(self.anchor_map.itervalues()))
@@ -502,17 +506,17 @@ class Convert(object):
                 span = self.wrap_elems(spans, SPAN())
             span.tag = 'a'
             self.resolved_link_map[hyperlink] = span
-            tgt = get(hyperlink, 'w:tgtFrame')
+            tgt = self.namespace.get(hyperlink, 'w:tgtFrame')
             if tgt:
                 span.set('target', tgt)
-            tt = get(hyperlink, 'w:tooltip')
+            tt = self.namespace.get(hyperlink, 'w:tooltip')
             if tt:
                 span.set('title', tt)
-            rid = get(hyperlink, 'r:id')
+            rid = self.namespace.get(hyperlink, 'r:id')
             if rid and rid in relationships_by_id:
                 span.set('href', relationships_by_id[rid])
                 continue
-            anchor = get(hyperlink, 'w:anchor')
+            anchor = self.namespace.get(hyperlink, 'w:anchor')
             if anchor and anchor in self.anchor_map:
                 span.set('href', '#' + self.anchor_map[anchor])
                 continue
@@ -576,7 +580,7 @@ class Convert(object):
         text = Text(ans, 'text', [])
 
         for child in run:
-            if is_tag(child, 'w:t'):
+            if self.namespace.is_tag(child, 'w:t'):
                 if not child.text:
                     continue
                 space = child.get(XML('space'), None)
@@ -596,11 +600,11 @@ class Convert(object):
                     ans.append(text.elem)
                 else:
                     text.buf.append(ctext)
-            elif is_tag(child, 'w:cr'):
+            elif self.namespace.is_tag(child, 'w:cr'):
                 text.add_elem(BR())
                 ans.append(text.elem)
-            elif is_tag(child, 'w:br'):
-                typ = get(child, 'w:type')
+            elif self.namespace.is_tag(child, 'w:br'):
+                typ = self.namespace.get(child, 'w:type')
                 if typ in {'column', 'page'}:
                     br = BR(style='page-break-after:always')
                 else:
@@ -611,25 +615,25 @@ class Convert(object):
                         br = BR()
                 text.add_elem(br)
                 ans.append(text.elem)
-            elif is_tag(child, 'w:drawing') or is_tag(child, 'w:pict'):
+            elif self.namespace.is_tag(child, 'w:drawing') or self.namespace.is_tag(child, 'w:pict'):
                 for img in self.images.to_html(child, self.current_page, self.docx, self.dest_dir):
                     text.add_elem(img)
                     ans.append(text.elem)
-            elif is_tag(child, 'w:footnoteReference') or is_tag(child, 'w:endnoteReference'):
+            elif self.namespace.is_tag(child, 'w:footnoteReference') or self.namespace.is_tag(child, 'w:endnoteReference'):
                 anchor, name = self.footnotes.get_ref(child)
                 if anchor and name:
                     l = SUP(A(name, href='#' + anchor, title=name), id='back_%s' % anchor)
                     l.set('class', 'noteref')
                     text.add_elem(l)
                     ans.append(text.elem)
-            elif is_tag(child, 'w:tab'):
+            elif self.namespace.is_tag(child, 'w:tab'):
                 spaces = int(math.ceil((self.settings.default_tab_stop / 36) * 6))
                 text.add_elem(SPAN(NBSP * spaces))
                 ans.append(text.elem)
                 ans[-1].set('class', 'tab')
-            elif is_tag(child, 'w:noBreakHyphen'):
+            elif self.namespace.is_tag(child, 'w:noBreakHyphen'):
                 text.buf.append(u'\u2011')
-            elif is_tag(child, 'w:softHyphen'):
+            elif self.namespace.is_tag(child, 'w:softHyphen'):
                 text.buf.append(u'\u00ad')
         if text.buf:
             setattr(text.elem, text.attr, ''.join(text.buf))
