@@ -260,6 +260,9 @@ class BooksView(QTableView):  # {{{
         h = self.column_header
 
         if action == 'hide':
+            if h.hiddenSectionCount() >= h.count():
+                return error_dialog(self, _('Cannot hide all columns'), _(
+                    'You must not hide all columns'), show=True)
             h.setSectionHidden(idx, True)
         elif action == 'show':
             h.setSectionHidden(idx, False)
@@ -1051,7 +1054,7 @@ class BooksView(QTableView):  # {{{
             self.select_rows([id_to_select], using_ids=True)
         elif self._model.highlight_only:
             self.clearSelection()
-        if self.isVisible():
+        if self.isVisible() and getattr(txt, 'as_you_type', False) is not True:
             self.setFocus(Qt.OtherFocusReason)
 
     def connect_to_search_box(self, sb, search_done):
