@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 from __future__ import (unicode_literals, division, absolute_import, print_function)
-store_version = 6 # Needed for dynamic plugin loading
+store_version = 7 # Needed for dynamic plugin loading
 
 __license__ = 'GPL 3'
 __copyright__ = '2011, John Schember <john@nachtimwald.com>'
@@ -55,6 +55,7 @@ class AmazonFRKindleStore(StorePlugin):
             allText = f.read()
             doc = html.fromstring(allText)#.decode('latin-1', 'replace'))
 
+            format_xpath2 = ''
             if doc.xpath('//div[@id = "atfResults" and contains(@class, "grid")]'):
                 #print('grid form')
                 data_xpath = '//div[contains(@class, "prod")]'
@@ -85,8 +86,8 @@ class AmazonFRKindleStore(StorePlugin):
             elif doc.xpath('//div[@id = "atfResults" and contains(@class, "list")]'):
                 #print('list form')
                 data_xpath = '//li[@class="s-result-item"]'
-                format_xpath = (
-                        './/h3[contains(@class, "s-inline")]/text()')
+                format_xpath = './/a[contains(@class, "a-size-small")]/text()'
+                format_xpath2 = './/h3[contains(@class, "s-inline")]/text()'
                 asin_xpath = '@data-asin'
                 cover_xpath = './/img[contains(@class, "cfMarker")]/@src'
                 title_xpath = './/h2[contains(@class, "s-access-title")]/text()'
@@ -111,7 +112,11 @@ class AmazonFRKindleStore(StorePlugin):
                 # if it isn't.
                 format_ = ''.join(data.xpath(format_xpath))
                 if 'kindle' not in format_.lower():
-                    continue
+                    if format_xpath2:
+                        format_ = ''.join(data.xpath(format_xpath2))
+                        if 'kindle' not in format_.lower():
+                            # print(etree.tostring(data, pretty_print=True))
+                            continue
 
                 # We must have an asin otherwise we can't easily reference the
                 # book later.
