@@ -16,7 +16,7 @@ __builtin__.__dict__['_'] = lambda s: s
 # immediately translated to the environment language
 __builtin__.__dict__['__'] = lambda s: s
 
-from calibre.constants import iswindows, preferred_encoding, plugins, isosx, islinux, isfrozen
+from calibre.constants import iswindows, preferred_encoding, plugins, isosx, islinux, isfrozen, DEBUG
 
 _run_once = False
 winutil = winutilerror = None
@@ -55,16 +55,24 @@ if not _run_once:
     # Convert command line arguments to unicode
     enc = preferred_encoding
     if isosx:
-        # Newer versions of OS X seem to use UTF-8
-        try:
-            [x.decode('utf-8') for x in sys.argv[1:]]
-            enc = 'utf-8'
-        except:
-            pass
+        enc = 'utf-8'
     for i in range(1, len(sys.argv)):
         if not isinstance(sys.argv[i], unicode):
             sys.argv[i] = sys.argv[i].decode(enc, 'replace')
 
+    #
+    # Ensure that the max number of open files is at least 1024
+    if not iswindows:
+        import resource
+        soft, hard = resource.getrlimit(resource.RLIMIT_NOFILE)
+        if soft < 1024:
+            try:
+                resource.setrlimit(resource.RLIMIT_NOFILE, (min(1024, hard), hard))
+            except Exception:
+                if DEBUG:
+                    import traceback
+                    traceback.print_exc()
+
     #
     # Setup resources
     import calibre.utils.resources as resources
