@@ -13,7 +13,7 @@ Test a binary calibre build to ensure that all needed binary images/libraries ha
 '''
 
 import cStringIO, os, ctypes
-from calibre.constants import plugins, iswindows, islinux
+from calibre.constants import plugins, iswindows, islinux, isosx
 
 def test_dlls():
     import win32api
@@ -75,6 +75,15 @@ def test_lxml():
     else:
         raise RuntimeError('lxml failed')
 
+def test_certgen():
+    from calibre.utils.certgen import create_key_pair
+    create_key_pair()
+
+def test_fsevents():
+    from fsevents import Observer, Stream
+    del Observer, Stream
+    print ('macfsevents OK!')
+
 def test_winutil():
     from calibre.devices.scanner import win_pnp_drives
     from calibre.constants import plugins
@@ -159,6 +168,12 @@ def test_icu():
     test_build()
     print ('ICU OK!')
 
+def test_dukpy():
+    print ('Testing dukpy')
+    from duktape import test_build
+    test_build()
+    print ('dukpy OK!')
+
 def test_wpd():
     wpd = plugins['wpd'][0]
     try:
@@ -217,12 +232,14 @@ def test():
     if iswindows:
         test_dlls()
     test_plugins()
+    test_dukpy()
     test_lxml()
     test_ssl()
     test_sqlite()
     test_apsw()
     test_imaging()
     test_unrar()
+    test_certgen()
     test_icu()
     test_woff()
     test_qt()
@@ -240,6 +257,8 @@ def test():
         test_terminal()
     if islinux:
         test_dbus()
+    if isosx:
+        test_fsevents()
 
 if __name__ == '__main__':
     test()
